Index: src/cpu-profiler.h |
diff --git a/src/cpu-profiler.h b/src/cpu-profiler.h |
index 82d8ff91cb53dc0f1ed9ecdadfb000b66b4f4203..5f263d1a9fe2b9799a20040b6249c1b38ea03299 100644 |
--- a/src/cpu-profiler.h |
+++ b/src/cpu-profiler.h |
@@ -104,9 +104,10 @@ class CodeAliasEventRecord : public CodeEventRecord { |
class TickSampleEventRecord BASE_EMBEDDED { |
public: |
// In memory, the first machine word of a TickSampleEventRecord will be the |
- // first entry of TickSample, that is -- a program counter field. |
+ // first entry of TickSample, that is -- the VM state field. |
// TickSample is put first, because 'order' can become equal to |
// SamplingCircularQueue::kClear, while program counter can't. |
TickSample sample; |
unsigned order; |
@@ -172,6 +173,8 @@ class ProfilerEventsProcessor : public Thread { |
bool ProcessCodeEvent(unsigned* dequeue_order); |
bool ProcessTicks(unsigned dequeue_order); |
+ INLINE(static bool FilterOutCodeCreateEvent(Logger::LogEventsAndTags tag)); |
+ |
ProfileGenerator* generator_; |
bool running_; |
CircularQueue<CodeEventsContainer> events_buffer_; |
@@ -236,8 +239,7 @@ class CpuProfiler { |
static void SetterCallbackEvent(String* name, Address entry_point); |
static INLINE(bool is_profiling()) { |
- ASSERT(singleton_ != NULL); |
- return singleton_->processor_ != NULL; |
+ return singleton_ != NULL && singleton_->processor_ != NULL; |
} |
private: |
@@ -104,9 +104,10 @@ class CodeAliasEventRecord : public CodeEventRecord { |
// TickSample is put first, because 'order' can become equal to |
- // SamplingCircularQueue::kClear, while program counter can't. |
+ // SamplingCircularQueue::kClear, while VM state can't, see |
+ // the definition of 'enum StateTag'. |
TickSample sample; |
unsigned order; |